==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeTcpSocketFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeTcpSocketFluentImpl<A extends ReadinessProbeTcpSocketFluent<A>> extends BaseFluent<A> implements ReadinessProbeTcpSocketFluent<A>{
  public ReadinessProbeTcpSocketFluentImpl() {
  }
  public ReadinessProbeTcpSocketFluentImpl(ReadinessProbeTcpSocket instance) {
    this.withTcpSocket(instance.getTcpSocket()); 
  }
  private TCPHealthCheckConfigBuilder tcpSocket;
  
  /**
   * This method has been deprecated, please use method buildTcpSocket instead.
   * @return The buildable object.
   */
  @Deprecated
  public TCPHealthCheckConfig getTcpSocket() {
    return this.tcpSocket!=null ?this.tcpSocket.build():null;
  }
  public TCPHealthCheckConfig buildTcpSocket() {
    return this.tcpSocket!=null ?this.tcpSocket.build():null;
  }
  public A withTcpSocket(TCPHealthCheckConfig tcpSocket) {
    _visitables.get("tcpSocket").remove(this.tcpSocket);
    if (tcpSocket!=null){ this.tcpSocket= new TCPHealthCheckConfigBuilder(tcpSocket); _visitables.get("tcpSocket").add(this.tcpSocket);} else { this.tcpSocket = null; _visitables.get("tcpSocket").remove(this.tcpSocket); } return (A) this;
  }
  public Boolean hasTcpSocket() {
    return this.tcpSocket != null;
  }
  public A withNewTcpSocket(String host,Integer port) {
    return (A)withTcpSocket(new TCPHealthCheckConfig(host, port));
  }
  public ReadinessProbeTcpSocketFluent.TcpSocketNested<A> withNewTcpSocket() {
    return new ReadinessProbeTcpSocketFluentImpl.TcpSocketNestedImpl();
  }
  public ReadinessProbeTcpSocketFluent.TcpSocketNested<A> withNewTcpSocketLike(TCPHealthCheckConfig item) {
    return new ReadinessProbeTcpSocketFluentImpl.TcpSocketNestedImpl(item);
  }
  public ReadinessProbeTcpSocketFluent.TcpSocketNested<A> editTcpSocket() {
    return withNewTcpSocketLike(getTcpSocket());
  }
  public ReadinessProbeTcpSocketFluent.TcpSocketNested<A> editOrNewTcpSocket() {
    return withNewTcpSocketLike(getTcpSocket() != null ? getTcpSocket(): new TCPHealthCheckConfigBuilder().build());
  }
  public ReadinessProbeTcpSocketFluent.TcpSocketNested<A> editOrNewTcpSocketLike(TCPHealthCheckConfig item) {
    return withNewTcpSocketLike(getTcpSocket() != null ? getTcpSocket(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ReadinessProbeTcpSocketFluentImpl that = (ReadinessProbeTcpSocketFluentImpl) o;
    if (tcpSocket != null ? !tcpSocket.equals(that.tcpSocket) :that.tcpSocket != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tcpSocket,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tcpSocket != null) { sb.append("tcpSocket:"); sb.append(tcpSocket); }
    sb.append("}");
    return sb.toString();
  }
  class TcpSocketNestedImpl<N> extends TCPHealthCheckConfigFluentImpl<ReadinessProbeTcpSocketFluent.TcpSocketNested<N>> implements ReadinessProbeTcpSocketFluent.TcpSocketNested<N>,Nested<N>{
    TcpSocketNestedImpl(TCPHealthCheckConfig item) {
      this.builder = new TCPHealthCheckConfigBuilder(this, item);
    }
    TcpSocketNestedImpl() {
      this.builder = new TCPHealthCheckConfigBuilder(this);
    }
    TCPHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeTcpSocketFluentImpl.this.withTcpSocket(builder.build());
    }
    public N endTcpSocket() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeTcpSocketFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeTcpSocketFluentImpl<A extends ReadinessProbeTcpSocketFluent<A>> extends BaseFluent<A> implements ReadinessProbeTcpSocketFluent<A>{
  public ReadinessProbeTcpSocketFluentImpl() {
  }
  public ReadinessProbeTcpSocketFluentImpl(ReadinessProbeTcpSocket instance) {
    if (instance != null) {
      this.withTcpSocket(instance.getTcpSocket());
    }
  }
  private TCPHealthCheckConfigBuilder tcpSocket;
  
  /**
   * This method has been deprecated, please use method buildTcpSocket instead.
   * @return The buildable object.
   */
  @Deprecated
  public TCPHealthCheckConfig getTcpSocket() {
    return this.tcpSocket!=null ?this.tcpSocket.build():null;
  }
  public TCPHealthCheckConfig buildTcpSocket() {
    return this.tcpSocket!=null ?this.tcpSocket.build():null;
  }
  public A withTcpSocket(TCPHealthCheckConfig tcpSocket) {
    _visitables.get("tcpSocket").remove(this.tcpSocket);
    if (tcpSocket!=null){ this.tcpSocket= new TCPHealthCheckConfigBuilder(tcpSocket); _visitables.get("tcpSocket").add(this.tcpSocket);} else { this.tcpSocket = null; _visitables.get("tcpSocket").remove(this.tcpSocket); } return (A) this;
  }
  public Boolean hasTcpSocket() {
    return this.tcpSocket != null;
  }
  public A withNewTcpSocket(String host,Integer port) {
    return (A)withTcpSocket(new TCPHealthCheckConfig(host, port));
  }
  public ReadinessProbeTcpSocketFluentImpl.TcpSocketNested<A> withNewTcpSocket() {
    return new ReadinessProbeTcpSocketFluentImpl.TcpSocketNestedImpl();
  }
  public ReadinessProbeTcpSocketFluentImpl.TcpSocketNested<A> withNewTcpSocketLike(TCPHealthCheckConfig item) {
    return new ReadinessProbeTcpSocketFluentImpl.TcpSocketNestedImpl(item);
  }
  public ReadinessProbeTcpSocketFluentImpl.TcpSocketNested<A> editTcpSocket() {
    return withNewTcpSocketLike(getTcpSocket());
  }
  public ReadinessProbeTcpSocketFluentImpl.TcpSocketNested<A> editOrNewTcpSocket() {
    return withNewTcpSocketLike(getTcpSocket() != null ? getTcpSocket(): new TCPHealthCheckConfigBuilder().build());
  }
  public ReadinessProbeTcpSocketFluentImpl.TcpSocketNested<A> editOrNewTcpSocketLike(TCPHealthCheckConfig item) {
    return withNewTcpSocketLike(getTcpSocket() != null ? getTcpSocket(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeTcpSocketFluentImpl that = (ReadinessProbeTcpSocketFluentImpl) o;
    if (!java.util.Objects.equals(tcpSocket, that.tcpSocket)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tcpSocket,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tcpSocket != null) { sb.append("tcpSocket:"); sb.append(tcpSocket); }
    sb.append("}");
    return sb.toString();
  }
  class TcpSocketNestedImpl<N> extends TCPHealthCheckConfigFluentImpl<ReadinessProbeTcpSocketFluentImpl.TcpSocketNested<N>> implements ReadinessProbeTcpSocketFluentImpl.TcpSocketNested<N>,Nested<N>{
    TcpSocketNestedImpl(TCPHealthCheckConfig item) {
      this.builder = new TCPHealthCheckConfigBuilder(this, item);
    }
    TcpSocketNestedImpl() {
      this.builder = new TCPHealthCheckConfigBuilder(this);
    }
    TCPHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeTcpSocketFluentImpl.this.withTcpSocket(builder.build());
    }
    public N endTcpSocket() {
      return and();
    }
    
  }
  
}
